function [predVisWeightEst,predVisWeightStdErr] = PredictVisualWeight(audThreshEst,visThreshEst,audThreshStdErr,visThreshStdErr)
% function [predVisWeightEst,predVisWeightStdErr] = PredictVisualWeight(audThreshEst,visThreshEst,audThreshStdErr,visThreshStdErr)
%
% This function calculates the predicted visual cue weights based upon the
% relative reliabilities (i.e., inverse of estimated thresholds) of the constituent 
% auditory and visual (single-sensory) stimuli. It also returns a standard
% error of the predicted visual weight by propagating the uncertainties 
% associated with the auditory and visual threshold estimates.
%
% Equation for predicted visual weight:
% predVisWeight = (audSigma^2) / (audSigma^2 + visSigma^2),
% where sigma indicates the estimated threshold for the given modality
% (i.e., second moment of the psychometric function).
%
% Note: This function requires the MATLAB Symbolic Math Toolbox, as well
% as the "PropError.m" function written by Brad Ridder (2007) and freely
% available online at the MATLAB Central File Exchange. A slightly
% modified version of the PropError.m function is included with this tutorial
% package under the BSD guidelines.
%
% John Sheppard, 25-July-2013

syms audSigma visSigma

predVisWeight = audSigma^2 / (audSigma^2 + visSigma^2);

[predVisWeightEst,predVisWeightStdErr] = PropError(predVisWeight,[audSigma, visSigma],[audThreshEst, visThreshEst],[audThreshStdErr, visThreshStdErr]);

end % EOF