% Figure 3 generating script.
% John Sheppard, July 24, 2013
% Questions? sheppard@cshl.edu

close('all');

%% Fig. 3a

clear

% NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
load('../data/human1_psychFits.mat');

cueConflicts = -2:2;
cueConflictIndexes = [1 3 5]; % These indexes point to cueConflicts of -2,0,2.

% RGB colors used for multisensory conflict conditions.
colorMap = [237 36 36; 106 189 69; 58 83 164]/255;

figure(1); clf(1); hold on;

% Plot in Fig. 3a depicts high rel. aud/low rel. vis multisensory trials.
audRelLevel = 2;
visRelLevel = 1;

for cueConflictCount = 1:numel(cueConflictIndexes)
    
    cueConflictIndex = cueConflictIndexes(cueConflictCount);
    cueConflict = cueConflicts(cueConflictCount);
    
    thisColor = colorMap(cueConflictCount,:);
    
    % Select the psychometric data pertaining to this multisensory trial type.
    choiceDataByRate = psychFits.trialTypes(6).conflictLevels(cueConflictIndex).choiceDataByRate;
    psychCurve = psychFits.trialTypes(6).conflictLevels(cueConflictIndex).psychCurve;

    % Plot the fitted psychometric curve.
    plot(psychCurve(:,1),psychCurve(:,2),'-','Color',thisColor,'LineWidth',2);
    
    for eventRateCount = 1:size(choiceDataByRate,1);
        thisEventRate = choiceDataByRate(eventRateCount,1);
        numTrialsChoseHigh = choiceDataByRate(eventRateCount,2);
        numTrials = choiceDataByRate(eventRateCount,3);
        highRateChoicePropEst = numTrialsChoseHigh/numTrials;
        highRateChoicePropStdErr = sqrt(highRateChoicePropEst*(1-highRateChoicePropEst)/numTrials);
        highRateChoicePropConfInt = [highRateChoicePropEst-highRateChoicePropStdErr, highRateChoicePropEst+highRateChoicePropStdErr];
        plot(thisEventRate, highRateChoicePropEst,'o','Color',thisColor,'MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor);
        plot([thisEventRate,thisEventRate],highRateChoicePropConfInt,'-','Color',thisColor,'LineWidth',1.5);
    end

end

fontSize = 18;
set(gca,'tickdir','out','Box','off','ylim',[0 1],'ytick',0:.25:1,'xlim',[7.8 14.2],'xtick',7:15,'fontname','times','fontsize',fontSize);
xlabel('Average event rate (events/s)','fontname','times','fontsize',fontSize);
ylabel('Proportion high choices','fontname','times','fontsize',fontSize);


%% Fig. 3c

figure(2); clf(2); hold on;

% Left panel in Fig. 3c depicts regression plot of PSE vs. cue conflict
% for high rel. aud/low rel. vis multisensory trials.

cueConflicts = -2:1:2;
cueConflictIndexes = 1:numel(cueConflicts);

PSEEsts = nan(1,numel(cueConflicts));
PSEStdErrs = nan(1,numel(cueConflicts));

for cueConflictCount = 1:numel(cueConflicts);
    
    cueConflictIndex = cueConflictIndexes(cueConflictCount);
    cueConflict = cueConflicts(cueConflictIndex);
    
    % Select the psychometric data pertaining to this multisensory trial type.
    % (trialType #6)
    psychParams = psychFits.trialTypes(6).conflictLevels(cueConflictIndex).psychParams;
    
    PSEEsts(cueConflictCount) = psychParams(5).est;
    PSEStdErrs(cueConflictCount) = psychParams(5).stdErr;
    
end

% Plot individual PSE estimates with error bars for each conflict level.
errorbar(cueConflicts,PSEEsts,PSEStdErrs,'o','MarkerFaceColor','k','MarkerEdgeColor','k','Color','k');
% Get regression coefficients
regCoeffs = glmfit(cueConflicts,PSEEsts);
% Get PSEs estimated by regression.
regEstimatedPSEs = regCoeffs(1) + regCoeffs(2)*cueConflicts;
% Plot best-fit regression line
plot(cueConflicts([1,end]),regEstimatedPSEs([1,end]),'-k','linewidth',1);
set(gca,'ylim',[8 13.5],'YTick',8:13,'yticklabel',{'','9','','11','','13'},'xlim',[-2.5,2.5],'xtick',-2:2,'FontSize',fontSize,'fontname','times');
set(gca,'box','off','tickdir','out');
xlabel('\Delta (events/s)','FontSize',fontSize,'fontname','times');
ylabel('PSE (events/s)','FontSize',fontSize,'fontname','times');

%%
% Right panel
figure(3); clf(3); hold on;

% Right panel in Fig. 3b depicts low rel. aud/high rel. vis multisensory trials.
% Runs same exact code as for left panel, but with opposite reliability
% levels.

cueConflicts = -2:1:2;
cueConflictIndexes = 1:numel(cueConflicts);

PSEEsts = nan(1,numel(cueConflicts));
PSEStdErrs = nan(1,numel(cueConflicts));

for cueConflictCount = 1:numel(cueConflicts);
    
    cueConflictIndex = cueConflictIndexes(cueConflictCount);
    cueConflict = cueConflicts(cueConflictIndex);
    
    % Select the psychometric data pertaining to this multisensory trial type.
    % (trialType #7)
    psychParams = psychFits.trialTypes(7).conflictLevels(cueConflictIndex).psychParams;
    
    PSEEsts(cueConflictCount) = psychParams(5).est;
    PSEStdErrs(cueConflictCount) = psychParams(5).stdErr;
    
end

% Plot individual PSE estimates with error bars for each conflict level.
errorbar(cueConflicts,PSEEsts,PSEStdErrs,'o','MarkerFaceColor','k','MarkerEdgeColor','k','Color','k');
% Get regression coefficients
regCoeffs = glmfit(cueConflicts,PSEEsts);
% Get PSEs estimated by regression.
regEstimatedPSEs = regCoeffs(1) + regCoeffs(2)*cueConflicts;
% Plot best-fit regression line
plot(cueConflicts([1,end]),regEstimatedPSEs([1,end]),'-k','linewidth',1);
set(gca,'ylim',[8 13.5],'YTick',8:13,'yticklabel',{'','9','','11','','13'},'xlim',[-2.5,2.5],'xtick',-2:2,'FontSize',fontSize,'fontname','times');
set(gca,'box','off','tickdir','out');
xlabel('\Delta (events/s)','FontSize',fontSize,'fontname','times');
ylabel('PSE (events/s)','FontSize',fontSize,'fontname','times');

%% Fig. 3e

% Scatterplot comparing predicted and observed weights in example human for 
% the "unmatched reliability" multisensory trials.
figure(4); clf(4); hold on;

% Define plot colors for observed and predicted weights
predictedColor = [121 124 187]/255;
observedColor = [58 83 164]/255;

% Plot in Fig. 3e shows visual weight for high rel. aud/low rel. vis trials
% on left, then low rel aud./high rel. vis trials on right.
% These correspond to trialType indexes 6 and 7 in the psychParams data
% structures.
trialTypeIndexes = [6 7];

% NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
load('../data/human1_psychFits.mat');

for trialTypeCount = 1:numel(trialTypeIndexes)
    
    trialTypeIndex = trialTypeIndexes(trialTypeCount);
    
    predVisWeightEsts(trialTypeCount) = psychFits.trialTypes(trialTypeIndex).predVisWeightEst;
    predVisWeightStdErrs(trialTypeCount) = psychFits.trialTypes(trialTypeIndex).predVisWeightStdErr;
    
    visWeightEsts(trialTypeCount) = psychFits.trialTypes(trialTypeIndex).visWeightEst;
    visWeightStdErrs(trialTypeCount) = psychFits.trialTypes(trialTypeIndex).visWeightStdErr;
    
end

errorbar([0.85 1.85],predVisWeightEsts,predVisWeightStdErrs,'o','color',predictedColor,'linewidth',2);
plot([0.85 1.85],predVisWeightEsts,'linewidth',1.5,'color',predictedColor);
errorbar([1.15 2.15],visWeightEsts,visWeightStdErrs,'o','color',observedColor,'linewidth',2);
plot([1.15 2.15],visWeightEsts,'linewidth',1.5,'color',observedColor);

set(gca,'ylim',[0 1.2],'ytick',0:.2:1,'xlim',[0.8 2.2],'xtick',1:2,'xticklabel',{'high rel. aud, low rel. vis','low rel. aud, high rel. vis'});
set(gca,'fontname','times','fontsize',20,'tickdir','out','box','off');
ylabel('Visual cue weight','fontname','times','fontsize',20)

%% Fig. 3b

clear

% NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
load('../data/rat3_psychFits.mat');

cueConflicts = [-2 0 2];
cueConflictIndexes = 1:3; % These indexes point to cueConflicts of -2,0,2.

% RGB colors used for multisensory conflict conditions.
colorMap = [237 36 36; 106 189 69; 58 83 164]/255;

figure(5); clf(5); hold on;

% Plot in Fig. 3a depicts high rel. aud/low rel. vis multisensory
% trials.
audRelLevel = 2;
visRelLevel = 1;

for cueConflictCount = 1:numel(cueConflictIndexes)

    cueConflictIndex = cueConflictIndexes(cueConflictCount);
    cueConflict = cueConflicts(cueConflictCount);
    
    thisColor = colorMap(cueConflictCount,:);
    
    % Select the psychometric data pertaining to this multisensory trial type.
    choiceDataByRate = psychFits.trialTypes(5).conflictLevels(cueConflictIndex).choiceDataByRate;
    psychParams = psychFits.trialTypes(5).conflictLevels(cueConflictIndex).psychParams;
    
    % Note: For plotting purposes, the multisensory rat psychometric curves are constrained to 
    % the range of 10-15 Hz. The average event rates of conflict trials
    % fall within this range (i.e., lowest/highest possible rates at +/- 2
    % conflict: 9/11 and 14/16 Hz, mean rates = 10 Hz, 15
    % Hz). The zero conflict condition extends to mean rates of 9 and 16
    % Hz; these rates were used in estimating the psychometric function for
    % the zero conflict condition but are omitted from the plot for
    % consistency with the +2/-2 conflict conditions.
    startRate = 10; endRate = 15;
    timeStep = 0.01;
    xRange = startRate:timeStep:endRate;
    theta = [psychParams(1:4).est];
    constrainedPmf = theta(4) + (1-theta(3)-theta(4)).*0.5*(1+erf(1./sqrt(2).*(xRange-theta(1))./theta(2)));
    psychCurve = [xRange(:),constrainedPmf(:)];
    
    % Plot the fitted psychometric curve.
    plot(psychCurve(:,1),psychCurve(:,2),'-','Color',thisColor,'LineWidth',2);
    
    for eventRateCount = 1:size(choiceDataByRate,1);
        thisEventRate = choiceDataByRate(eventRateCount,1);
        numTrialsChoseHigh = choiceDataByRate(eventRateCount,2);
        numTrials = choiceDataByRate(eventRateCount,3);
        highRateChoicePropEst = numTrialsChoseHigh/numTrials;
        highRateChoicePropStdErr = sqrt(highRateChoicePropEst*(1-highRateChoicePropEst)/numTrials);
        highRateChoicePropConfInt = [highRateChoicePropEst-highRateChoicePropStdErr, highRateChoicePropEst+highRateChoicePropStdErr];
        plot(thisEventRate, highRateChoicePropEst,'o','Color',thisColor,'MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor);
        plot([thisEventRate,thisEventRate],highRateChoicePropConfInt,'-','Color',thisColor,'LineWidth',1.5);
    end

end

fontSize = 18;
set(gca,'tickdir','out','Box','off','ylim',[0 1],'ytick',0:.25:1,'xlim',[9.8 15.2],'xtick',9:16,'fontname','times','fontsize',fontSize);
xlabel('Average event rate (events/s)','fontname','times','fontsize',fontSize);
ylabel('Proportion high choices','fontname','times','fontsize',fontSize);


%% Fig. 3d

figure(6); clf(6); hold on;

% Left panel in Fig. 3d depicts regression plot of PSE vs. cue conflict
% for high rel. aud/vis multisensory trials in example rat.

cueConflicts = [-2 0 2];
cueConflictIndexes = 1:numel(cueConflicts);

PSEEsts = nan(1,numel(cueConflicts));
PSEStdErrs = nan(1,numel(cueConflicts));

for cueConflictCount = 1:numel(cueConflicts);
    
    cueConflictIndex = cueConflictIndexes(cueConflictCount);
    cueConflict = cueConflicts(cueConflictCount);
    
    % Select the psychometric data pertaining to this multisensory trial type.
    % (trialType #5)
    psychParams = psychFits.trialTypes(5).conflictLevels(cueConflictIndex).psychParams;
    
    PSEEsts(cueConflictCount) = psychParams(5).est;
    PSEStdErrs(cueConflictCount) = psychParams(5).stdErr;
    
end

% Plot individual PSE estimates with error bars for each conflict level.
errorbar(cueConflicts,PSEEsts,PSEStdErrs,'o','MarkerFaceColor','k','MarkerEdgeColor','k','Color','k');
% Get regression coefficients
regCoeffs = glmfit(cueConflicts,PSEEsts);
% Get PSEs estimated by regression.
regEstimatedPSEs = regCoeffs(1) + regCoeffs(2)*cueConflicts;
% Plot best-fit regression line
plot(cueConflicts([1,end]),regEstimatedPSEs([1,end]),'-k','linewidth',1);
set(gca,'ylim',[10.5 13],'YTick',10.5:.5:13,'yticklabel',{'','11','','12','','13'},'xlim',[-2.5,2.5],'xtick',-2:2,'FontSize',fontSize,'fontname','times');
set(gca,'box','off','tickdir','out');
xlabel('\Delta (events/s)','FontSize',fontSize,'fontname','times');
ylabel('PSE (events/s)','FontSize',fontSize,'fontname','times');

%% 
% Right panel in Fig. 3d depicts regression plot of PSE vs. cue conflict
% for low rel. aud/vis multisensory trials in example rat.

figure(7); clf(7); hold on;

cueConflicts = [-2 0 2];
cueConflictIndexes = 1:numel(cueConflicts);

PSEEsts = nan(1,numel(cueConflicts));
PSEStdErrs = nan(1,numel(cueConflicts));

for cueConflictCount = 1:numel(cueConflicts);
    
    cueConflictIndex = cueConflictIndexes(cueConflictCount);
    cueConflict = cueConflicts(cueConflictCount);
    
    % Select the psychometric data pertaining to this multisensory trial type.
    % (trialType #4)
    psychParams = psychFits.trialTypes(4).conflictLevels(cueConflictIndex).psychParams;
    
    PSEEsts(cueConflictCount) = psychParams(5).est;
    PSEStdErrs(cueConflictCount) = psychParams(5).stdErr;
    
end

% Plot individual PSE estimates with error bars for each conflict level.
errorbar(cueConflicts,PSEEsts,PSEStdErrs,'o','MarkerFaceColor','k','MarkerEdgeColor','k','Color','k');
% Get regression coefficients
regCoeffs = glmfit(cueConflicts,PSEEsts);
% Get PSEs estimated by regression.
regEstimatedPSEs = regCoeffs(1) + regCoeffs(2)*cueConflicts;
% Plot best-fit regression line
plot(cueConflicts([1,end]),regEstimatedPSEs([1,end]),'-k','linewidth',1);
set(gca,'ylim',[10.5 13],'YTick',10.5:.5:13,'yticklabel',{'','11','','12','','13'},'xlim',[-2.5,2.5],'xtick',-2:2,'FontSize',fontSize,'fontname','times');
set(gca,'box','off','tickdir','out');
xlabel('\Delta (events/s)','FontSize',fontSize,'fontname','times');
ylabel('PSE (events/s)','FontSize',fontSize,'fontname','times');

%% Fig. 3f

% Scatterplot comparing predicted and observed weights in example rat for 
% the "unmatched reliability" multisensory trials.
figure(8); clf(8); hold on;

% Define plot colors for observed and predicted weights
predictedColor = [121 124 187]/255;
observedColor = [58 83 164]/255;

% Plot in Fig. 3f shows visual weight for high rel. aud/vis trials
% on left, then low rel aud./vis trials on right.
% These correspond to trialType indexes 5 and 4 in the psychParams data
% structures.
trialTypeIndexes = [5 4];

% NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
load('../data/rat3_psychFits.mat');

for trialTypeCount = 1:numel(trialTypeIndexes)
    
    trialTypeIndex = trialTypeIndexes(trialTypeCount);
    
    predVisWeightEsts(trialTypeCount) = psychFits.trialTypes(trialTypeIndex).predVisWeightEst;
    predVisWeightStdErrs(trialTypeCount) = psychFits.trialTypes(trialTypeIndex).predVisWeightStdErr;
    
    visWeightEsts(trialTypeCount) = psychFits.trialTypes(trialTypeIndex).visWeightEst;
    visWeightStdErrs(trialTypeCount) = psychFits.trialTypes(trialTypeIndex).visWeightStdErr;
    
end

errorbar([0.85 1.85],predVisWeightEsts,predVisWeightStdErrs,'o','color',predictedColor,'linewidth',2);
plot([0.85 1.85],predVisWeightEsts,'linewidth',1.5,'color',predictedColor);
errorbar([1.15 2.15],visWeightEsts,visWeightStdErrs,'o','color',observedColor,'linewidth',2);
plot([1.15 2.15],visWeightEsts,'linewidth',1.5,'color',observedColor);

set(gca,'ylim',[0 1.2],'ytick',0:.2:1,'xlim',[0.8 2.2],'xtick',1:2,'xticklabel',{'high rel. aud, vis','low rel. aud, vis'});
set(gca,'fontname','times','fontsize',20,'tickdir','out','box','off');
ylabel('Visual cue weight','fontname','times','fontsize',20);


