% Figure 5 generating script.
% John Sheppard, July 24, 2013
% Questions? sheppard@cshl.edu

close('all');

%% Fig. 5a
% Simulation of decisions based on all evidence presented throughout trial.

figure(1); clf(1); hold on;

% Call function simulateEvidenceAccumulation.m and specify an accumulation
% period of 1000 ms (i.e., the entire stimulus, 0-1000 ms).
% See the simulateEvidenceAccumulation.m function for more details.
simulateEvidenceAccumulation(1000);

%% Fig. 5b
% Simulation of decisions based only on evidence presented at first half of trial.

figure(2); clf(2); hold on;

% Call function simulateEvidenceAccumulation.m and specify an accumulation
% period of 500 ms (i.e., only the first half of the stimulus, 0-500 ms).
% See the simulateEvidenceAccumulation.m function for more details.
simulateEvidenceAccumulation(500);

%% Fig. 5c
% Auditory excess rate curves for example human subject.

% NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
load('../data/human1_psychFits.mat');

trialTypeIndexes = [1 2];

% Set colors for plots.
colorMap = [69 103 176; 0 100 0]/255;

figure(3); clf(3); hold on;

for trialTypeCount = 1:numel(trialTypeIndexes)
    
    thisColor = colorMap(trialTypeCount,:);
    trialTypeIndex = trialTypeIndexes(trialTypeCount);
    timeVector = psychFits.trialTypes(trialTypeIndex).excessRateResults.timeVector;
    thisExcessRateEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateEsts;
    thisExcessRateStdErr = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateStdErrs;
    thisExcessRateShuffleEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateShuffleEsts;
    stimDuration = psychFits.trialTypes(trialTypeIndex).excessRateResults.stimDuration;
    
    % Apply a moving-average filter with a filter width of 130 ms (current
    % index + 6 indexes on either flank = 1+6+6 = 13 = 130 ms moving
    % average). This is only to smooth out artifacts from the excess rate
    % due to arrival of discrete events over the trial duration (i.e., for
    % clarity of display). It was not applied to the raw data when computing
    % statistics or for extracting points in the excess rate timecourses
    % plotted in Fig. 6c.
    % For this step we used the function movingAverage.m, authored by Carlos Adrin
    % Vargas Aguilera and freely available online at
    % http://www.mathworks.com/matlabcentral/fileexchange/12276-movingavera
    % ge-v3-1-mar-2008. A copy of this function is included with this
    % tutorial.
    thisExcessRateEst = movingAverage(thisExcessRateEst,6);
    thisExcessRateStdErr = movingAverage(thisExcessRateStdErr,6);
    thisExcessRateShuffleEst = movingAverage(thisExcessRateShuffleEst,6);
    
    % Plot the excess rate curve and bootstrapped standard error using boundedLine.m.
    % boundedLine (c) 2010-2012 Kelly Kearney, freely available on MatLAB
    % Central File Exchange. This function is included with this tutorial
    % under the BSD guidelines.
    [hl,hp]=boundedLine(timeVector,thisExcessRateEst,thisExcessRateStdErr,'cmap',thisColor);
    delete(hl);
    plot(timeVector,thisExcessRateEst,'-','color',thisColor,'linewidth',2);
    
    % Plot the excess rate "shuffle" control curve.
    plot(timeVector,thisExcessRateShuffleEst,'--','color',thisColor,'linewidth',2);
    
    xlabel('Time preceding end of stimulus (ms)','fontname','times','fontsize',22);
    ylabel('Excess rate (events/s)','fontname','times','fontsize',22);
    
    xTickLabels = -1 * fliplr(200:200:stimDuration-100);
    
    set(gca,'tickdir','out','box','off','xticklabel',xTickLabels,'xlim',[100 930],'xtick',200:200:stimDuration-100);
    set(gca,'ylim',[-1 5],'ytick',-1:5,'yticklabel',{'','0','1','2','3','4','5'},'fontname','times','fontsize',18);
    set(gcf,'paperposition',[0.25 5 8 5]);
    
end

%% Fig. 5d
% Auditory excess rate curves for example rat subject.

% NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
load('../data/rat3_psychFits.mat');

trialTypeIndexes = [1 2];

% Set colors for plots
colorMap = [69 103 176; 0 100 0; 0 0 0]/255;

figure(4); clf(4); hold on;

for trialTypeCount = 1:numel(trialTypeIndexes)
    
    thisColor = colorMap(trialTypeCount,:);
    trialTypeIndex = trialTypeIndexes(trialTypeCount);
    timeVector = psychFits.trialTypes(trialTypeIndex).excessRateResults.timeVector;
    thisExcessRateEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateEsts;
    thisExcessRateStdErr = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateStdErrs;
    thisExcessRateShuffleEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateShuffleEsts;
    stimDuration = psychFits.trialTypes(trialTypeIndex).excessRateResults.stimDuration;
    
    thisExcessRateEst = movingAverage(thisExcessRateEst,6);
    thisExcessRateStdErr = movingAverage(thisExcessRateStdErr,6);
    thisExcessRateShuffleEst = movingAverage(thisExcessRateShuffleEst,6);

    [hl,hp]=boundedLine(timeVector,thisExcessRateEst,thisExcessRateStdErr,'cmap',thisColor);
    delete(hl);
    plot(timeVector,thisExcessRateEst,'-','color',thisColor,'linewidth',2);
    
    % Plot the excess rate "shuffle" control curve.
    plot(timeVector,thisExcessRateShuffleEst,'--','color',thisColor,'linewidth',2);
    
    xlabel('Time preceding end of stimulus (ms)','fontname','times','fontsize',22);
    ylabel('Excess rate (events/s)','fontname','times','fontsize',22);
    
    xTickLabels = -1 * fliplr(200:200:stimDuration-100);
    
    set(gca,'tickdir','out','box','off','xticklabel',xTickLabels,'xlim',[100 930],'xtick',200:200:stimDuration-100);
    set(gca,'ylim',[-.5 2],'ytick',-.5:.5:2,'yticklabel',{'','0','0.5','1','1.5','2'},'fontname','times','fontsize',18);
    set(gcf,'paperposition',[0.25 5 8 5]);
    
end


%% Fig. 5e
% Visual excess rate curves from human subject showing an atypical strategy.

% NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
load('../data/human4_psychFits.mat');

trialTypeIndexes = [3 4];

% Set colors for plots
colorMap = [130 130 130; 0 0 0]/255;

figure(5); clf(5); hold on;

for trialTypeCount = 1:numel(trialTypeIndexes)
    
    thisColor = colorMap(trialTypeCount,:);
    trialTypeIndex = trialTypeIndexes(trialTypeCount);
    timeVector = psychFits.trialTypes(trialTypeIndex).excessRateResults.timeVector;
    thisExcessRateEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateEsts;
    thisExcessRateStdErr = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateStdErrs;
    thisExcessRateShuffleEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateShuffleEsts;
    stimDuration = psychFits.trialTypes(trialTypeIndex).excessRateResults.stimDuration;
    
    thisExcessRateEst = movingAverage(thisExcessRateEst,6);
    thisExcessRateStdErr = movingAverage(thisExcessRateStdErr,6);
    thisExcessRateShuffleEst = movingAverage(thisExcessRateShuffleEst,6);
    
    [hl,hp]=boundedLine(timeVector,thisExcessRateEst,thisExcessRateStdErr,'cmap',thisColor);
    delete(hl);
    plot(timeVector,thisExcessRateEst,'-','color',thisColor,'linewidth',2);
    
    % Plot the excess rate "shuffle" control curve.
    plot(timeVector,thisExcessRateShuffleEst,'--','color',thisColor,'linewidth',2);
    
    xlabel('Time preceding end of stimulus (ms)','fontname','times','fontsize',22);
    ylabel('Excess rate (events/s)','fontname','times','fontsize',22);
    
    xTickLabels = -1 * fliplr(200:200:stimDuration-100);
    
    set(gca,'tickdir','out','box','off','xticklabel',xTickLabels,'xlim',[100 930],'xtick',200:200:stimDuration-100);
    set(gca,'ylim',[-0.5 3],'ytick',-.5:.5:3,'yticklabel',{'','0','','1','','2','','3'},'fontname','times','fontsize',18);
    set(gcf,'paperposition',[0.25 5 8 5]);
    
end
